==> archibald-7.x-2.1.tar.gz: archibald/includes/languages/de.php <==
<?php

/**
 * @file
 * List  ISO 639-1 language codes and its german names
 */
$languages = array(
  'aa' => 'Afar',
  'ab' => 'Abchasisch',
  'af' => 'Afrikaans',
  'am' => 'Amharisch',
  'ar' => 'Arabisch',
  'as' => 'Assamesisch',
  'ay' => 'Aymará-Sprache',
  'az' => 'Aserbaidschanisch',
  'ba' => 'Baschkirisch',
  'be' => 'Weißrussisch',
  'bg' => 'Bulgarisch',
  'bh' => 'Biharisch',
  'bi' => 'Bislama',
  'bn' => 'Bengalisch',
  'bo' => 'Tibetisch',
  'br' => 'Bretonisch',
  'ca' => 'Katalanisch',
  'co' => 'Korsisch',
  'cs' => 'Tschechisch',
  'cy' => 'Kymrisch',
  'da' => 'Dänisch',
  'de' => 'Deutsch',
  'dz' => 'Bhutanisch',
  'el' => 'Griechisch',
  'en' => 'Englisch',
  'eo' => 'Esperanto',
  'es' => 'Spanisch',
  'et' => 'Estnisch',
  'eu' => 'Baskisch',
  'fa' => 'Persisch',
  'fi' => 'Finnisch',
  'fj' => 'Fidschianisch',
  'fo' => 'Färöisch',
  'fr' => 'Französisch',
  'fy' => 'Friesisch',
  'ga' => 'Irisch',
  'gd' => 'Schottisch-Gälisch',
  'gl' => 'Galizisch',
  'gn' => 'Guarani',
  'gu' => 'Gujarati',
  'ha' => 'Hausa',
  'he' => 'Hebräisch',
  'hi' => 'Hindi',
  'hr' => 'Kroatisch',
  'hu' => 'Ungarisch',
  'hy' => 'Armenisch',
  'ia' => 'Interlingua',
  'id' => 'Indonesisch',
  'ie' => 'Interlingue',
  'ik' => 'Inupiak',
  'is' => 'Isländisch',
  'it' => 'Italienisch',
  'iu' => 'Inukitut',
  'iw' => 'ehemaligen Hebräisch',
  'in' => 'ehemaligen Indonesisch',
  'ja' => 'Japanisch',
  'jw' => 'Javanisch',
  'ji' => 'ehemaligen jiddischen',
  'ka' => 'Georgisch',
  'kk' => 'Kasachisch',
  'kl' => 'Grönländisch',
  'km' => 'Kambodschanisch',
  'kn' => 'Kannada',
  'ko' => 'Koreanisch',
  'ks' => 'Kaschmirisch',
  'ku' => 'Kurdisch',
  'ky' => 'Kirgisisch',
  'la' => 'Latein',
  'ln' => 'Lingala',
  'lo' => 'Laotisch',
  'lt' => 'Litauisch',
  'lv' => 'Lettisch',
  'mg' => 'Madagassisch',
  'mi' => 'Maori',
  'mk' => 'Mazedonisch',
  'ml' => 'Malayalam',
  'mn' => 'Mongolisch',
  'mo' => 'Moldauisch',
  'mr' => 'Marathi',
  'ms' => 'Malaiisch',
  'mt' => 'Maltesisch',
  'my' => 'Birmanisch',
  'na' => 'Nauruisch',
  'ne' => 'Nepalesisch',
  'nl' => 'Niederländisch',
  'no' => 'Norwegisch',
  'oc' => 'Okzitanisch',
  'om' => 'Oromo',
  'or' => 'Orija',
  'pa' => 'Pandschabisch',
  'pl' => 'Polnisch',
  'ps' => 'Afghanisch (Paschtu)',
  'pt' => 'Portugiesisch',
  'qu' => 'Quechua',
  'rm' => 'Rätoromanisch',
  'rm2907' => 'Rhaeto-Romance Puter',
  'rm2908' => 'Rhaeto-Romance Rumantsch grischun',
  'rm16068' => 'Rhaeto-Romance Surmiran',
  'rm16069' => 'Rhaeto-Romance Sursilvan',
  'rm13312' => 'Rhaeto-Romance Sutsilvan',
  'rm2906' => 'Rhaeto-Romance Vallader',
  'rn' => 'Rundi-Sprache',
  'ro' => 'Rumänisch',
  'ru' => 'Russisch',
  'rw' => 'Ruandisch',
  'sa' => 'Sanskrit',
  'sd' => 'Sindhi',
  'sg' => 'Sango',
  'sh' => 'Serbo-Kroatisch',
  'si' => 'Singhalesisch',
  'sk' => 'Slowakisch',
  'sl' => 'Slowenisch',
  'sm' => 'Samoanisch',
  'sn' => 'Shona',
  'so' => 'Somali',
  'sq' => 'Albanisch',
  'sr' => 'Serbisch',
  'ss' => 'Swazi',
  'st' => 'Süd-Sotho-Sprache',
  'su' => 'Sudanesisch',
  'sv' => 'Schwedisch',
  'sw' => 'Suaheli',
  'ta' => 'Tamilisch',
  'te' => 'Telugu',
  'tg' => 'Tadschikisch',
  'th' => 'Thai',
  'ti' => 'Tigrinja',
  'tk' => 'Turkmenisch',
  'tl' => 'Tagalog',
  'tn' => 'Tswana-Sprache',
  'to' => 'Tongaisch',
  'tr' => 'Türkisch',
  'ts' => 'Tsonga',
  'tt' => 'Tatarisch',
  'tw' => 'Twi',
  'ug' => 'Uigurisch',
  'uk' => 'Ukrainisch',
  'ur' => 'Urdu',
  'uz' => 'Usbekisch',
  'vi' => 'Vietnamesisch',
  'vo' => 'Volapük',
  'wo' => 'Wolof',
  'xh' => 'Xhosa',
  'yi' => 'Jiddisch',
  'yo' => 'Joruba',
  'za' => 'Zhuang',
  'zh' => 'Chinesisch',
  'zu' => 'Zulu',
);

==> archibald-7.x-2.8.tar.gz: archibald/includes/languages/de.php <==
<?php

/**
 * @file
 * List  ISO 639-1 language codes and its german names
 */
$languages = array(
  'aa' => 'Afar',
  'ab' => 'Abchasisch',
  'af' => 'Afrikaans',
  'am' => 'Amharisch',
  'ar' => 'Arabisch',
  'as' => 'Assamesisch',
  'ay' => 'Aymará-Sprache',
  'az' => 'Aserbaidschanisch',
  'ba' => 'Baschkirisch',
  'be' => 'Weißrussisch',
  'bg' => 'Bulgarisch',
  'bh' => 'Biharisch',
  'bi' => 'Bislama',
  'bn' => 'Bengalisch',
  'bo' => 'Tibetisch',
  'br' => 'Bretonisch',
  'ca' => 'Katalanisch',
  'co' => 'Korsisch',
  'cs' => 'Tschechisch',
  'cy' => 'Kymrisch',
  'da' => 'Dänisch',
  'de' => 'Deutsch',
  'dz' => 'Bhutanisch',
  'el' => 'Griechisch',
  'en' => 'Englisch',
  'eo' => 'Esperanto',
  'es' => 'Spanisch',
  'et' => 'Estnisch',
  'eu' => 'Baskisch',
  'fa' => 'Persisch',
  'fi' => 'Finnisch',
  'fj' => 'Fidschianisch',
  'fo' => 'Färöisch',
  'fr' => 'Französisch',
  'fy' => 'Friesisch',
  'ga' => 'Irisch',
  'gd' => 'Schottisch-Gälisch',
  'gl' => 'Galizisch',
  'gn' => 'Guarani',
  'gu' => 'Gujarati',
  'ha' => 'Hausa',
  'he' => 'Hebräisch',
  'hi' => 'Hindi',
  'hr' => 'Kroatisch',
  'hu' => 'Ungarisch',
  'hy' => 'Armenisch',
  'ia' => 'Interlingua',
  'id' => 'Indonesisch',
  'ie' => 'Interlingue',
  'ik' => 'Inupiak',
  'is' => 'Isländisch',
  'it' => 'Italienisch',
  'iu' => 'Inukitut',
  'iw' => 'ehemaligen Hebräisch',
  'in' => 'ehemaligen Indonesisch',
  'ja' => 'Japanisch',
  'jw' => 'Javanisch',
  'ji' => 'ehemaligen jiddischen',
  'ka' => 'Georgisch',
  'kk' => 'Kasachisch',
  'kl' => 'Grönländisch',
  'km' => 'Kambodschanisch',
  'kn' => 'Kannada',
  'ko' => 'Koreanisch',
  'ks' => 'Kaschmirisch',
  'ku' => 'Kurdisch',
  'ky' => 'Kirgisisch',
  'la' => 'Latein',
  'ln' => 'Lingala',
  'lo' => 'Laotisch',
  'lt' => 'Litauisch',
  'lv' => 'Lettisch',
  'mg' => 'Madagassisch',
  'mi' => 'Maori',
  'mk' => 'Mazedonisch',
  'ml' => 'Malayalam',
  'mn' => 'Mongolisch',
  'mo' => 'Moldauisch',
  'mr' => 'Marathi',
  'ms' => 'Malaiisch',
  'mt' => 'Maltesisch',
  'my' => 'Birmanisch',
  'na' => 'Nauruisch',
  'ne' => 'Nepalesisch',
  'nl' => 'Niederländisch',
  'no' => 'Norwegisch',
  'oc' => 'Okzitanisch',
  'om' => 'Oromo',
  'or' => 'Orija',
  'pa' => 'Pandschabisch',
  'pl' => 'Polnisch',
  'ps' => 'Afghanisch (Paschtu)',
  'pt' => 'Portugiesisch',
  'qu' => 'Quechua',
  'rm' => 'Rätoromanisch',
  'rm2907' => 'Puter',
  'rm2908' => 'Rumantsch grischun',
  'rm16068' => 'Surmiran',
  'rm16069' => 'Sursilvan',
  'rm13312' => 'Sutsilvan',
  'rm2906' => 'Vallader',
  'rn' => 'Rundi-Sprache',
  'ro' => 'Rumänisch',
  'ru' => 'Russisch',
  'rw' => 'Ruandisch',
  'sa' => 'Sanskrit',
  'sd' => 'Sindhi',
  'sg' => 'Sango',
  'sh' => 'Serbo-Kroatisch',
  'si' => 'Singhalesisch',
  'sk' => 'Slowakisch',
  'sl' => 'Slowenisch',
  'sm' => 'Samoanisch',
  'sn' => 'Shona',
  'so' => 'Somali',
  'sq' => 'Albanisch',
  'sr' => 'Serbisch',
  'ss' => 'Swazi',
  'st' => 'Süd-Sotho-Sprache',
  'su' => 'Sudanesisch',
  'sv' => 'Schwedisch',
  'sw' => 'Suaheli',
  'ta' => 'Tamilisch',
  'te' => 'Telugu',
  'tg' => 'Tadschikisch',
  'th' => 'Thai',
  'ti' => 'Tigrinja',
  'tk' => 'Turkmenisch',
  'tl' => 'Tagalog',
  'tn' => 'Tswana-Sprache',
  'to' => 'Tongaisch',
  'tr' => 'Türkisch',
  'ts' => 'Tsonga',
  'tt' => 'Tatarisch',
  'tw' => 'Twi',
  'ug' => 'Uigurisch',
  'uk' => 'Ukrainisch',
  'ur' => 'Urdu',
  'uz' => 'Usbekisch',
  'vi' => 'Vietnamesisch',
  'vo' => 'Volapük',
  'wo' => 'Wolof',
  'xh' => 'Xhosa',
  'yi' => 'Jiddisch',
  'yo' => 'Joruba',
  'za' => 'Zhuang',
  'zh' => 'Chinesisch',
  'zu' => 'Zulu',
);
